@@ -387,9 +387,21 @@ class ViewParameters(tk.Frame):
           label = tk.Label(self, text="    ", font=LARGE_FONT)
           label.grid(row=1,column=6)
           
-          ttk.Button(self, text="View video for all wells together", command=lambda: controller.showValidationVideo(-1,0,-1)).grid(row=1,column=1)
+          ttk.Button(self, text="View video for all wells together", command=lambda: controller.showValidationVideo(-1,numPoiss,0,-1)).grid(row=1,column=1)
           
-          # ttk.Button(self, text="Verify wells detection", command=lambda: controller.showValidationVideo(-1,0,-1)).grid(row=1,column=2, columnspan=2)
+          buttonLabel = "View "
+          if controller.graphScaling:
+            buttonLabel = buttonLabel + "Zoomed In "
+          else:
+            buttonLabel = buttonLabel + "Zoomed Out "
+          if controller.visualization == 0:
+            buttonLabel = buttonLabel + "tail angle smoothed"
+          elif controller.visualization == 1:
+            buttonLabel = buttonLabel + "tail angle raw"
+          else:
+            buttonLabel = buttonLabel + "body coordinates"
+          buttonLabel = buttonLabel + " for all bouts combined"
+          ttk.Button(self, text=buttonLabel, command=lambda: controller.showGraphForAllBoutsCombined(numWell, numPoiss, dataRef, controller.visualization, controller.graphScaling)).grid(row=1, column=2, columnspan=5)
           
           label = tk.Label(self, text=name, font="bold", justify=LEFT, pady=10)
           label.grid(sticky=W, row=0, column=0, columnspan=8)
@@ -402,7 +414,7 @@ class ViewParameters(tk.Frame):
           tk.Button(self, text="-", command=lambda: controller.printSomeResults(int(e1.get())-1,e2.get(),e3.get())).grid(row=2,column=3)
           tk.Button(self, text="+", command=lambda: controller.printSomeResults(int(e1.get())+1,e2.get(),e3.get())).grid(row=2,column=4)
           
-          ttk.Button(self, text="View zoomed video for well "+str(numWell), command=lambda: controller.showValidationVideo(e1.get(),1,-1)).grid(row=3,column=2)
+          ttk.Button(self, text="View zoomed video for well "+str(numWell), command=lambda: controller.showValidationVideo(e1.get(),numPoiss,1,-1)).grid(row=3,column=2)
           
           def callback(url):
             webbrowser.open_new(url)
@@ -460,6 +472,11 @@ class ViewParameters(tk.Frame):
           
           tk.Button(self, text="Change Right Side Plot", command=lambda: controller.printSomeResults(e1.get(), e2.get(), e3.get(), True), bg="light green").grid(row=8,column=2, columnspan=2)
           
+          if controller.graphScaling:
+            tk.Button(self, text="Zoom out Graph", command=lambda: controller.printSomeResults(e1.get(), e2.get(), e3.get(), False, True), bg="light green").grid(row=8,column=3, columnspan=2)
+          else:
+            tk.Button(self, text="Zoom in Graph", command=lambda: controller.printSomeResults(e1.get(), e2.get(), e3.get(), False, True), bg="light green").grid(row=8,column=3, columnspan=2)
+          
           if (controller.superstructmodified == 1):
             button1 = tk.Button(self, text="Save SuperStruct", command=lambda: controller.saveSuperStruct(e1.get(),e2.get(),e3.get()))
             button1.configure(bg = 'orange')
@@ -470,9 +487,9 @@ class ViewParameters(tk.Frame):
               begMove = dataRef["wellPoissMouv"][numWell][numPoiss][numMouv]["BoutStart"]
               endMove = dataRef["wellPoissMouv"][numWell][numPoiss][numMouv]["BoutEnd"]
               
-              ttk.Button(self, text="View video for well "+str(numWell), command=lambda: controller.showValidationVideo(e1.get(),0,begMove)).grid(row=3,column=1)
+              ttk.Button(self, text="View video for well "+str(numWell), command=lambda: controller.showValidationVideo(e1.get(),numPoiss,0,begMove)).grid(row=3,column=1)
               
-              ttk.Button(self, text="View bout's video", command=lambda: controller.showValidationVideo(e1.get(),1,begMove)).grid(row=6,column=1)
+              ttk.Button(self, text="View bout's video", command=lambda: controller.showValidationVideo(e1.get(),numPoiss,1,begMove)).grid(row=6,column=1)
               
               if controller.visualization == 0 and not("TailAngle_smoothed" in dataRef["wellPoissMouv"][numWell][numPoiss][numMouv]):
                   controller.visualization = 1
@@ -531,6 +548,8 @@ class ViewParameters(tk.Frame):
                 
                 f = Figure(figsize=(5,5), dpi=100)
                 a = f.add_subplot(111)
+                if not(controller.graphScaling):
+                  a.set_ylim(-140, 140)
                 
                 if len(tailAngleSmoothed):
                   a.plot([i for i in range(begMove,endMove+1)],tailAngleSmoothed)
@@ -545,6 +564,8 @@ class ViewParameters(tk.Frame):
               
                 f = Figure(figsize=(5,5), dpi=100)
                 a = f.add_subplot(111)
+                if not(controller.graphScaling):
+                  a.set_ylim(-140, 140)
               
                 a.plot([i for i in range(begMove,endMove+1)],tailAngleSmoothed)
                 a.plot([i for i in range(begMove,endMove+1)],[0 for i in range(0,len(tailAngleSmoothed))])
@@ -557,6 +578,12 @@ class ViewParameters(tk.Frame):
                 f = Figure(figsize=(5,5), dpi=100)
                 a = f.add_subplot(111)
                 
+                if not(controller.graphScaling):
+                  lengthX  = dataRef["wellPositions"][numWell]["lengthX"]
+                  lengthY  = dataRef["wellPositions"][numWell]["lengthY"]
+                  a.set_xlim(0, lengthX)
+                  a.set_ylim(0, lengthY)
+                
                 a.plot(headX, headY)
               
               canvas = FigureCanvasTkAgg(f, self)
@@ -578,4 +605,13 @@ class ViewParameters(tk.Frame):
               
               canvas = Canvas(self)
               canvas.create_text(100,10, text="No bout detected for well "+str(numWell))
-              canvas.grid(row=2,column=7,rowspan=7)
\ No newline at end of file
+              canvas.grid(row=2,column=7,rowspan=7)
+
+class Error(tk.Frame):
+
+    def __init__(self, parent, controller):
+        tk.Frame.__init__(self, parent)
+        self.controller = controller
+        tk.Label(self, text="There was an error somewhere.").pack(side="top", fill="x", pady=10)
+        tk.Label(self, text="Check the command line to see what the error was.").pack(side="top", fill="x", pady=10)
+        tk.Button(self, text="Go to the start page", bg="light cyan", command=lambda: controller.show_frame("StartPage")).pack()
