@@ -8,11 +8,8 @@ from tkinter import *
 def headEmbededGUI(self, controller, blackBack, whiteBack, noBoutDetect, boutDetection, tweakTrackingParamsYes, 
 tweakTrackingParamsNo):
   
-  # self.configFile["invertBlackWhiteOnImages"] = int(whiteBack)
-  # self.configFile["headEmbededAutoSet_ExtendedDescentSearchOption"] = int(optionExtendedDescentSearchOption)
-  # self.configFile["headEmbededAutoSet_BackgroundExtractionOption" ] = int(optionBackgroundExtractionOption) * 7
-  
-  self.configFile["extractBackWhiteBackground"] = int(whiteBack)
+  self.configFile["invertBlackWhiteOnImages"] = int(whiteBack)
+  self.configFile["extractBackWhiteBackground"] = 0
   
   self.configFile["automaticallySetSomeOfTheHeadEmbededHyperparameters"] = 1
   self.configFile["findHeadPositionByUserInput"] = 1
@@ -32,10 +29,9 @@ tweakTrackingParamsNo):
   self.configFile["headingCalculationMethod"] = "calculatedWithMedianTailTip"
   
   if int(boutDetection) or int(tweakTrackingParamsYes):
-    self.configFile["noBoutsDetection"] = 0
+    # self.configFile["noBoutsDetection"] = 0
     self.configFile["extractAdvanceZebraParameters"] = 1
     self.calculateBackground(controller, 0)
-    # controller.show_frame("AdujstParamInsideAlgo")
   else:
     self.configFile["noBoutsDetection"] = 1
     controller.show_frame("FinishConfig")
