@@ -102,7 +102,7 @@ def findRectangularWells(frame, videoPath, hyperparameters, rectangularWellsArea
           if math.sqrt(point[0][0]**2 + point[0][1]**2) > bottomRightDistToZero:
             bottomRightDistToZero = math.sqrt(point[0][0]**2 + point[0][1]**2)
             bottomRightCoord = point[0]
-        stretchDist = int(math.sqrt((bottomRightCoord[0] - topLeftCoord[0]) * (bottomRightCoord[1] - topLeftCoord[1])) * (rectangularWellStretchPercentage / 100))
+        stretchDist = int(math.sqrt((bottomRightCoord[0] - topLeftCoord[0] if bottomRightCoord[0] - topLeftCoord[0] >= 0 else 0) * (bottomRightCoord[1] - topLeftCoord[1] if bottomRightCoord[1] - topLeftCoord[1] >= 0 else 0)) * (rectangularWellStretchPercentage / 100))
         well = {'topLeftX': int(topLeftCoord[0] - stretchDist), 'topLeftY': int(topLeftCoord[1] - stretchDist), 'lengthX': int(bottomRightCoord[0] - topLeftCoord[0] + 2 * stretchDist), 'lengthY': int(bottomRightCoord[1] - topLeftCoord[1] + 2 * stretchDist)}
       else:
         top    = float("inf")
@@ -198,6 +198,26 @@ def findCircularWells(frame, videoPath, hyperparameters):
   return wellPositions
 
 
+def saveWellsRepartitionImage(wellPositions, frame, hyperparameters):
+  rectangleTickness = 2
+  lengthY = len(frame)
+  lengthX = len(frame[0])
+  if len(wellPositions):
+    perm1 = np.random.permutation(len(wellPositions)) * int(255/len(wellPositions))
+    perm2 = np.random.permutation(len(wellPositions)) * int(255/len(wellPositions))
+    perm3 = np.random.permutation(len(wellPositions)) * int(255/len(wellPositions))
+    for i in range(0, len(wellPositions)):
+      if hyperparameters["wellsAreRectangles"] or len(hyperparameters["oneWellManuallyChosenTopLeft"]) or int(hyperparameters["multipleROIsDefinedDuringExecution"]) or hyperparameters["noWellDetection"]:
+        topLeft     = (wellPositions[i]['topLeftX'], wellPositions[i]['topLeftY'])
+        bottomRight = (wellPositions[i]['topLeftX'] + wellPositions[i]['lengthX'], wellPositions[i]['topLeftY'] + wellPositions[i]['lengthY'])
+        color = (int(perm1[i]), int(perm2[i]), int(perm3[i]))
+        frame = cv2.rectangle(frame, topLeft, bottomRight, color, rectangleTickness)
+      else:
+        cv2.circle(frame, (int(wellPositions[i]['topLeftX'] + wellPositions[i]['lengthX'] / 2), int(wellPositions[i]['topLeftY'] + wellPositions[i]['lengthY'] / 2)), 170, (0,0,255), 2)
+      cv2.putText(frame, str(i), (int(wellPositions[i]['topLeftX'] + wellPositions[i]['lengthX'] / 2), int(wellPositions[i]['topLeftY'] + wellPositions[i]['lengthY'] / 2)), cv2.FONT_HERSHEY_SIMPLEX, 4,(255,255,255),2,cv2.LINE_AA)
+  frame = cv2.resize(frame, (int(lengthX/2), int(lengthY/2))) # ???
+  cv2.imwrite(os.path.join(os.path.join(hyperparameters["outputFolder"], hyperparameters["videoName"]), "repartition.jpg"), frame )
+
 def findWells(videoPath, hyperparameters):
 
   if hyperparameters["noWellDetection"]:
@@ -205,11 +225,14 @@ def findWells(videoPath, hyperparameters):
     cap = cv2.VideoCapture(videoPath)
     if (cap.isOpened()== False): 
       print("Error opening video stream or file")
+    ret, frame = cap.read()
     frame_width  = int(cap.get(3))
     frame_height = int(cap.get(4))
     l = []
     well = { 'topLeftX' : 0 , 'topLeftY' : 0 , 'lengthX' : frame_width , 'lengthY': frame_height }
     l.append(well)
+    saveWellsRepartitionImage(l, frame, hyperparameters)
+    cap.release()
     return l
   
   # Multiple ROIs defined by user during the execution
@@ -220,19 +243,8 @@ def findWells(videoPath, hyperparameters):
     if (cap.isOpened()== False): 
       print("Error opening video stream or file")
     ret, frame = cap.read()
-    root = tk.Tk()
-    horizontal = root.winfo_screenwidth()
-    vertical   = root.winfo_screenheight()
-    getRealValueCoefX = 1
-    getRealValueCoefY = 1
-    if len(frame[0]) > horizontal or len(frame) > vertical:
-      reduce = min(horizontal / len(frame[0]), vertical / len(frame))
-      newLengthX = int(len(frame[0]) * reduce)
-      newLengthY = int(len(frame)    * reduce)
-      getRealValueCoefX = len(frame[0]) / newLengthX
-      getRealValueCoefY = len(frame)    / newLengthY
-      frame = cv2.resize(frame, (newLengthX, newLengthY))
-    root.destroy()
+    frameForRepartitionJPG = frame.copy()
+    [frame, getRealValueCoefX, getRealValueCoefY, horizontal, vertical] = resizeImageTooLarge(frame, True, 0.85)
     cv2.waitKey(500)
     for i in range(0, int(hyperparameters["nbWells"])):
       WINDOW_NAME = "Click on the top left of one of the regions of interest"
@@ -241,6 +253,11 @@ def findWells(videoPath, hyperparameters):
       cvui.imshow(WINDOW_NAME, frame)
       while not(cvui.mouse(cvui.CLICK)):
         cursor = cvui.mouse()
+        frame2 = frame.copy()
+        frame2 = cv2.line(frame2, (cursor.x - 2000, cursor.y), (cursor.x + 2000, cursor.y), (0, 0, 255), 2)
+        frame2 = cv2.line(frame2, (cursor.x, cursor.y - 2000), (cursor.x, cursor.y + 2000), (0, 0, 255), 2)
+        cvui.imshow(WINDOW_NAME, frame2)
+        del frame2
         cv2.waitKey(20)
       topLeft = [cursor.x, cursor.y]
       cv2.destroyWindow(WINDOW_NAME)
@@ -250,16 +267,20 @@ def findWells(videoPath, hyperparameters):
       cvui.imshow(WINDOW_NAME, frame)
       while not(cvui.mouse(cvui.CLICK)):
         cursor = cvui.mouse()
+        frame2 = frame.copy()
+        frame2 = cv2.line(frame2, (cursor.x - 2000, cursor.y), (cursor.x + 2000, cursor.y), (0, 0, 255), 2)
+        frame2 = cv2.line(frame2, (cursor.x, cursor.y - 2000), (cursor.x, cursor.y + 2000), (0, 0, 255), 2)
+        cvui.imshow(WINDOW_NAME, frame2)
+        del frame2
         cv2.waitKey(20)
       bottomRight = [cursor.x, cursor.y]
       frame = cv2.rectangle(frame, (topLeft[0], topLeft[1]), (bottomRight[0], bottomRight[1]), (255, 0, 0), 1)
       cv2.destroyWindow(WINDOW_NAME)
-      topLeftX = int(topLeft[0] * getRealValueCoefX)
-      topLeftY = int(topLeft[1] * getRealValueCoefY)
-      frame_width  = int((bottomRight[0] - topLeft[0]) * getRealValueCoefX)
-      frame_height = int((bottomRight[1] - topLeft[1]) * getRealValueCoefY)
-      well = {'topLeftX' : topLeftX, 'topLeftY' : topLeftY, 'lengthX' : frame_width, 'lengthY': frame_height}
+      frame_width  = int(getRealValueCoefX * (bottomRight[0] - topLeft[0]))
+      frame_height = int(getRealValueCoefY * (bottomRight[1] - topLeft[1]))
+      well = {'topLeftX' : int(getRealValueCoefX * topLeft[0]), 'topLeftY' : int(getRealValueCoefY * topLeft[1]), 'lengthX' : frame_width, 'lengthY': frame_height}
       l.append(well)
+    saveWellsRepartitionImage(l, frameForRepartitionJPG, hyperparameters)
     cap.release()
     return l
   
@@ -275,6 +296,12 @@ def findWells(videoPath, hyperparameters):
     frame_height = bottomRight_Y - topLeft_Y
     well = { 'topLeftX' : topLeft_X , 'topLeftY' : topLeft_Y , 'lengthX' : frame_width , 'lengthY': frame_height }
     l.append(well)
+    cap = cv2.VideoCapture(videoPath)
+    if (cap.isOpened()== False): 
+      print("Error opening video stream or file")
+    ret, frame = cap.read()
+    saveWellsRepartitionImage(l, frame, hyperparameters)
+    cap.release()
     return l
   
   # Circular or rectangular wells
@@ -333,26 +360,26 @@ def findWells(videoPath, hyperparameters):
     
     print("Not enough wells detected, please adjust your configuration file")
   
-  # Creating validation image
-  
-  rectangleTickness = 2
   lengthY = len(frame)
   lengthX = len(frame[0])
+  
   if len(wellPositions):
-    perm1 = np.random.permutation(len(wellPositions)) * int(255/len(wellPositions))
-    perm2 = np.random.permutation(len(wellPositions)) * int(255/len(wellPositions))
-    perm3 = np.random.permutation(len(wellPositions)) * int(255/len(wellPositions))
     for i in range(0, len(wellPositions)):
-      if hyperparameters["wellsAreRectangles"]:
-        topLeft     = (wellPositions[i]['topLeftX'], wellPositions[i]['topLeftY'])
-        bottomRight = (wellPositions[i]['topLeftX'] + wellPositions[i]['lengthX'], wellPositions[i]['topLeftY'] + wellPositions[i]['lengthY'])
-        color = (int(perm1[i]), int(perm2[i]), int(perm3[i]))
-        frame = cv2.rectangle(frame, topLeft, bottomRight, color, rectangleTickness)
-      else:
-        cv2.circle(frame, (int(wellPositions[i]['topLeftX'] + wellPositions[i]['lengthX'] / 2), int(wellPositions[i]['topLeftY'] + wellPositions[i]['lengthY'] / 2)), 170, (0,0,255), 2)
-      cv2.putText(frame, str(i), (int(wellPositions[i]['topLeftX'] + wellPositions[i]['lengthX'] / 2), int(wellPositions[i]['topLeftY'] + wellPositions[i]['lengthY'] / 2)), cv2.FONT_HERSHEY_SIMPLEX, 4,(255,255,255),2,cv2.LINE_AA)
-  frame = cv2.resize(frame, (int(lengthX/2), int(lengthY/2))) # ???
-  cv2.imwrite(os.path.join(os.path.join(hyperparameters["outputFolder"], hyperparameters["videoName"]), "repartition.jpg"), frame )
+      topLeftX = wellPositions[i]['topLeftX']
+      wellPos_lengthX = wellPositions[i]['lengthX']
+      topLeftY = wellPositions[i]['topLeftY']
+      wellPos_lengthY = wellPositions[i]['lengthY']
+      if topLeftX < 0:
+        wellPositions[i]['topLeftX'] = 0
+      if topLeftY < 0:
+        wellPositions[i]['topLeftY'] = 0
+      if topLeftX + wellPos_lengthX >= lengthX:
+        wellPositions[i]['lengthX'] = lengthX - topLeftX - 1
+      if topLeftY + wellPos_lengthY >= lengthY:
+        wellPositions[i]['lengthY'] = lengthY - topLeftY - 1
+  
+  saveWellsRepartitionImage(wellPositions, frame, hyperparameters)
+  
   if hyperparameters["debugFindWells"]:
   
     frame2 = frame.copy()
@@ -366,6 +393,7 @@ def findWells(videoPath, hyperparameters):
     cv2.destroyWindow('Wells Detection')
   
   print("Wells found")
+  
   if hyperparameters["popUpAlgoFollow"]:
     popUpAlgoFollow.prepend("Wells found")
 
