@@ -101,8 +101,6 @@ def getHyperparameters(configFile, videoName, videoPath, argv):
   hyperparameters["thresForDetectMovementWithRawVideo"] = getConfig(config, "thresForDetectMovementWithRawVideo", videoPath)
   hyperparameters["minNbPixelForDetectMovementWithRawVideo"] = getConfig(config, "minNbPixelForDetectMovementWithRawVideo", videoPath)
   hyperparameters["frameGapComparision"]        = getConfig(config, "frameGapComparision", videoPath)
-  hyperparameters["firstFrame"]                 = getConfig(config, "firstFrame", videoPath)
-  hyperparameters["lastFrame"]                  = getConfig(config, "lastFrame", videoPath)
   hyperparameters["wellOutputVideoDiameter"]    = getConfig(config, "wellOutputVideoDiameter", videoPath)
   hyperparameters["fillGapFrameNb"]             = getConfig(config, "fillGapFrameNb", videoPath)
   hyperparameters["minPixelDiffForBackExtract"] = getConfig(config, "minPixelDiffForBackExtract", videoPath)
@@ -355,6 +353,13 @@ def getHyperparameters(configFile, videoName, videoPath, argv):
   hyperparameters["saveWellPositionsToBeReloadedNoMatterWhat"] = getConfig(config, "saveWellPositionsToBeReloadedNoMatterWhat", videoPath)
   hyperparameters["exitAfterWellsDetection"] = getConfig(config, "exitAfterWellsDetection", videoPath)
   
+  hyperparameters["additionalOutputFolder"] = getConfig(config, "additionalOutputFolder", videoPath)
+  hyperparameters["additionalOutputFolderOverwriteIfAlreadyExist"] = getConfig(config, "additionalOutputFolderOverwriteIfAlreadyExist", videoPath)
+  
+  hyperparameters["outputValidationVideoContrastImprovement"] = getConfig(config, "outputValidationVideoContrastImprovement", videoPath)
+  hyperparameters["outputValidationVideoContrastImprovementQuartile"] = getConfig(config, "outputValidationVideoContrastImprovementQuartile", videoPath)
+  
+  
   if len(argv) > 5 and not(argv[0] == "getTailExtremityFirstFrame"):
     i = 5
     while i < len(argv):
