@@ -1,3 +1,4 @@
+from zebrazoom.code.preprocessImage import preprocessImage
 import numpy as np
 import cv2
 
@@ -17,10 +18,16 @@ def headEmbededFrameBackExtract(videoPath, background, hyperparameters, frameNum
     cap.set(1, frameNumber)
     ret, frame = cap.read()
   
+  if hyperparameters["invertBlackWhiteOnImages"]:
+    frame = 255 - frame
+    
+  if hyperparameters["imagePreProcessMethod"]:
+    frame = preprocessImage(frame, hyperparameters)
+  
   kernel = np.ones((8,8),np.float32)/25
   thres1  = cv2.filter2D(frame,-1,kernel)
   retval, thres1 = cv2.threshold(thres1, 80, 255, cv2.THRESH_BINARY)
-    
+  
   frame  = cv2.cvtColor(frame, cv2.COLOR_BGR2GRAY)
   thres1 = cv2.cvtColor(thres1, cv2.COLOR_BGR2GRAY)
 
@@ -29,7 +36,7 @@ def headEmbededFrameBackExtract(videoPath, background, hyperparameters, frameNum
     cv2.waitKey(0)
   
   putToWhite = ( frame.astype('int32') >= (background.astype('int32') + minPixelDiffForBackExtract) )
-
+  # This puts the pixels that belong to a fish to white
   frame[putToWhite] = 255
   
   if (debug):
