@@ -1,7 +1,5 @@
-import sys
-sys.path.insert(1, './dataanalysis/')
+import zebrazoom
 import pickle
-from applyClustering import applyClustering
 
 # Applying the clustering on this dataframe
 
@@ -24,7 +22,7 @@ clusteringOptions = {
   'videoSaveFirstTenBouts' : False,
   'globalParametersCalculations' : True,
   'nbVideosToSave' : 10,
-  'resFolder' : './data/',
+  'resFolder' : 'data',
   'nameOfFile' : 'example'
 }
 
@@ -35,5 +33,5 @@ infile.close()
 clusteringOptions['nbFramesTakenIntoAccount'] = nbFramesTakenIntoAccount
 
 # Classifies bouts based on the clustering previously obtained
-[allBouts, c] = applyClustering(clusteringOptions, classifier, './resultsClustering/')
+[allBouts, c] = zebrazoom.applyClustering(clusteringOptions, classifier, 'resultsClustering')
 
